============================================
Command Line Interface (CLI) Helper Routines
============================================

This is a collection of routines that are useful when creating Command
Line Interface (CLI) programs.
